You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jackrabbit.apache.org by tr...@apache.org on 2010/02/26 11:46:20 UTC

svn commit: r916642 - /jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/xml/WorkspaceImporter.java

Author: tripod
Date: Fri Feb 26 10:46:19 2010
New Revision: 916642

URL: http://svn.apache.org/viewvc?rev=916642&view=rev
Log:
JCR-2521 WorkspaceImporter throws exception

Modified:
    jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/xml/WorkspaceImporter.java

Modified: jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/xml/WorkspaceImporter.java
URL: http://svn.apache.org/viewvc/jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/xml/WorkspaceImporter.java?rev=916642&r1=916641&r2=916642&view=diff
==============================================================================
--- jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/xml/WorkspaceImporter.java (original)
+++ jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/xml/WorkspaceImporter.java Fri Feb 26 10:46:19 2010
@@ -160,19 +160,21 @@
         parents.push(importTarget);
 
         // TODO: TOBEFIXED importer doesn't yet pass protected items to the configured importers.
         // for the time being throw exception if an importer is configured that
         // is expected to work with workspace import.
         if (config != null) {
             List<ProtectedNodeImporter> ln = config.getProtectedNodeImporters();
             for (ProtectedNodeImporter pni : ln) {
                 if (pni.init(session, session, true, uuidBehavior, refTracker)) {
-                    throw new UnsupportedOperationException("Workspace-Import of protected nodes: Not yet implement. ");
+                    log.warn("Protected node importer configured is not supported by workspace import.");
+                    //throw new UnsupportedOperationException("Workspace-Import of protected nodes: Not yet implement. ");
                 }
             }
             List<ProtectedPropertyImporter> lp = config.getProtectedPropertyImporters();
             for (ProtectedPropertyImporter ppi : lp) {
                 if (ppi.init(session, session, true, uuidBehavior, refTracker)) {
-                    throw new UnsupportedOperationException("Workspace-Import of protected properties: Not yet implement. ");
+                    log.warn("Protected property importer configured is not supported by workspace import.");
+                    //throw new UnsupportedOperationException("Workspace-Import of protected properties: Not yet implement. ");
                 }
             }
         }
@@ -160,19 +160,21 @@
 
         // TODO: TOBEFIXED importer doesn't yet pass protected items to the configured importers.
-        // for the time being throw exception if an importer is configured that
-        // is expected to work with workspace import.
+        // for the time being log an exception if an importer is configured that
+        // is expected to work with workspace import. see JCR-2521
         if (config != null) {
             List<ProtectedNodeImporter> ln = config.getProtectedNodeImporters();